/*
	error.c for AmigaDOS 3.0
	Print Message text for AmigaDOS errors along with probable causes
	and suggestions for recovery.

	N Fisketjn
*/

#include "stdio.h"
#include "stdlib.h"

void version(void)
{
	printf("$VER: Error 1.0 2.7.93");
}

void cause(void)
{
	printf("\n\033[3m  Probable cause:\033[0m\n");
}

void recovery(void)
{
	printf("\n\033[3m  Recovery suggestion:\033[0m\n");
}

void verify(void)
{
	printf("  Verify the correct command format.\n");
}

void incorrect(void)
{
	printf("  Incorrect command line.\n");
}

void main(argc,argv)
int argc;
char *argv[];

{  
	int code;
	  
    if (argc != 2) {
        printf("Usage: error \033[3merrorcode\033[0m\n");
        exit(0);
    }
    else {
        code = atoi(argv[1]);
        switch(code) {
            case 103: {
                printf("\033[3m  103: Not enough memory\033[0m\n");
                cause();
                printf("  Not enough memory in your Amiga to carry out the operation.\n");
                recovery();
                printf("  Close any unnecessary windows and applications, then re-issue the command. If it still doesn't work, reboot. Memory may be sufficient, but fragmented. It is possible that you may need to add more RAM to your system.\n");
                break;
            }
            case 104: {
                printf("\033[3m  104: Process table full\033[0m\n");
                cause();
                printf("  There is a limit to the number of possible processes.\n");
				recovery();
				printf("  Stop one or more tasks.\n");
                break;
            }
			case 114: {
				printf("\033[3m  114: Bad template\033[0\n");
				cause();
				incorrect();
				recovery();
				verify();
				break;
			}
			case 115: {
				printf("\033[3m  115: Bad number\033[0\n");
				cause();
				printf("  The program was expecting a numerical argument.\n");
				recovery();
				verify();
				break;
			}
			case 116: {
				printf("\033[3m  116: Required argument missing\033[0\n");
				cause();
				incorrect();
				recovery();
				verify();
				break;
			}
			case 117: {
				printf("\033[3m  117: Argument after '=' missing\033[0\n");
				cause();
				incorrect();
				recovery();
				verify();
				break;
			}
			case 118: {
				printf("\033[3m  118: Too many arguments\033[0\n");
				cause();
				incorrect();
				recovery();
				verify();
				break;
			}
			case 119: {
				printf("\033[3m  119: Unmatched quotes\033[0\n");
				cause();
				incorrect();
				recovery();
				verify();
				break;
			}
            case 120: {
                printf("\033[3m  120: Argument line invalid or too long\033[0m\n");
                cause();
                printf("  Your command line is incorrect or contains too many arguments.\n");
                recovery();
				verify();
	            break;
            }	
            case 121: {
                printf("\033[3m  121: File is not executable\033[0m\n");
                cause();
                printf("  You misspelled the command name, or the file may not be a loadable (program or script) file.\n");
                recovery();
                printf("  Retype the filename and make sure that the file is a program file. In order to execute a sqript, either the s bit must be set or the EXECUTE command must be used.\n");
                break;
            }
            case 122: {
                printf("\033[3m  122: Invalid resident library\033[0m\n");
				cause();
				printf("  You are trying to use commands with a previous version.\n");
				recovery();
				printf("  Reboot with the current version of AmigaDOS.\n"); 
                break;
            }
            case 202: {
                printf("\033[3m  202: Object in use\033[0m\n");
                cause();
                printf("  The specified file or directory is already being used by another application. If an application is reading a file, no other program can write to it, and vice versa.\n");
                recovery();
                printf("  Stop the other application that is using the file or directory, and re-issue the command.\n");
                break;
            }
            case 203: {
                printf("\033[3m  203: Object already exists\033[0m\n");
                cause();
                printf("  The name that you specified already belongs to another file or directory.\n");
                recovery();
                printf("  Use another name, or delete the existing file or directory, and replace it.\n");
                break;
            }
            case 204: {
                printf("\033[3m  204: Directory not found\033[0m\n");
				cause();
				printf("  AmigaDOS cannot find the directory you specified. You may have made a typing or spelling error.\n");
				recovery();
				printf("  Check the directory name (use DIR if necessary). Re-issue the command.\n");
                break;
            }
            case 205: {
                printf("\033[3m  205: Object not found\033[0m\n");
                cause();
                printf("  AmigaDOS cannot find the file or device you specified. You may have made a typing or spelling error.\n");
                recovery();
                printf("  Check the filename (use DIR) or the device name (use INFO). Re-issue the command.\n");
                break;
            }
            case 206: {
                printf("\033[3m  206: Invalid window description\033[0m\n");
                cause();
                printf("  This occurs when specifying a window size for a Shell, ED, or ICONX window. You may have made the window too big or too small, or you may have omitted an argument. This error also occurs with the NEWSHELL command, if you supply a device name that is not a window.\n");
                recovery();
                printf("  Re-issue the window specification.\n");
                break;
            }
            case 209: {
                printf("\033[3m  209: Packet request type unknown\033[0m\n");
                cause();
                printf("  You have asked a device handler to attempt an operation it cannot do. For example, the console handler cannot rename anything.\n");
                recovery();
                printf("  Check the request code passed to device handlers for the appropriate request.\n");
                break;
            }
            case 210: {
                printf("\033[3m  210: Object name invalid\033[0m\n");
                cause();
                printf("  There is an invalid character in the filename or the filename is too long.\n");
				recovery();
				printf("  Re-type the name, being sure not to use any invalid characters or exceed the maximum length.\n");
                break;
            }
            case 211: {
                printf("\033[3m  211: Invalid object lock\033[0m\n");
                cause();
                printf("  You have used something that is not a valid lock.\n");
                recovery();
                printf("  Check that your only passes valid locks to AmigaDOS calls that expect locks.\n");
                break;
            }
            case 212: {
                printf("\033[3m  212: Object not of required type\033[0m\n");
                cause();
                printf("  You may have specified a filename for an operation that requires a directory name, or vice versa.\n");
                recovery();
				verify();
                break;
            }
            case 213: {
                printf("\033[3m  213: Disk not validated\033[0m\n");
                cause();
                printf("  If you have just inserted a disk, the disk validation process may be in progress. It is also possible that the disk is corrupt.\n");
                recovery();
                printf("  If you've just inserted the disk, wait for the validation process to finish. This may take less than a minute for a floppy disk or up to several minutes for a hard disk. If the disk is corrupt, it cannot be validated. In this case, try to retrieve the disk's files and copy them to another disk.\n");
                break;
            }
            case 214: {
                printf("\033[3m  214: Disk is write-protected\033[0m\n");
                cause();
                printf("  The plastic tab is in the write-protect position.\n");
                recovery();
                printf("  Remove the disk, move the tab, and re-insert the disk. Or use a different disk.\n");
                break;
            }
            case 215: {
                printf("\033[3m  215: Rename across devices attempted\033[0m\n");
                cause();
                printf("  RENAME only changes a filename on the same volume. You can use RENAME to move a file from one directory to another, but you cannot move files from one volume to another.\n");
                recovery();
                printf("  Use COPY to copy the file to the destination volume. Delete it from the source volume, if desired. Then use RENAME.\n");
                break;
            }
            case 216: {
                printf("\033[3m  216: Directory not empty\033[0m\n");
                cause();
                printf("  This error occurs if you attempt to delete a directory that contains files or sudirectories.\n");
                recovery();
                printf("  If you are sure you want to delete the complete directory, use the ALL option of DELETE.\n");
                break;
            }
			case 217: {
				printf("\033[3m  217: Too many levels\033[0m\n");
				cause();
				printf("  You've exceeded the limit of 15 soft links.\n");
				recovery();
				printf("  Reduce the number of soft links.\n");
				break;
			}
            case 218: {
                printf("\033[3m  218: Device (or volume) not mounted\033[0m\n");
                cause();
                printf("  If the device is a floppy disk, it has not been inserted in a drive. If it is another type of device, it has not been mounted with MOUNT or the name is misspelled.\n");
                recovery();
                printf("  Insert the correct floppy disk, mount the device, check the spelling of the device name, or revise your MountList file.\n");
                break;
            }
            case 219: {
                printf("\033[3m  219: Seek error\033[0m\n");
                cause();
                printf("  You have attempted to call SEEK with invalid arguments.\n");
                recovery();
                printf("  Make sure that you only SEEK within the file. You cannot SEEK outside the bounds of the file.\n");
                break;
            }
            case 220: {
                printf("\033[3m  220: Comment is too long\033[0m\n");
                cause();
                printf("  Your filenote has exceeded the maximum number of characters (79).\n");
                recovery();
                printf("  Use a shorter filenote.\n");
                break;
            }
            case 221: {
                printf("\033[3m  221: Disk is full\033[0m\n");
                cause();
                printf("  There is not enough room on the disk to perform the requested operation.\n");
                recovery();
                printf("  Delete some unnecessary files or directories, or use a different disk.\n");
                break;
            }
            case 222: {
                printf("\033[3m  222: Object is protected from deletion\033[0m\n");
                cause();
                printf("  The d (deletable) protection bit of the file or directory is clear.\n");
                recovery();
                printf("  If you are certain that you want to delete the file or directory, use PROTECT to set the d bit or use the FORCE option of DELETE.\n");
                break;
            }
            case 223: { 
                printf("\033[3m  223: File is write protected\033[0m\n");
                cause();
                printf("  The w (writable) protection bit of the file is clear.\n");
                recovery();
                printf("  If you are certain that you want to overwrite the file, use PROTECT to set the w bit.\n");
                break;
            }
            case 224: { 
                printf("\033[3m  224: File is read protected\033[0m\n");
                cause();
                printf("  The r (readable) protection bit of the file is clear.\n");
                recovery();
                printf("  Use PROTECT to set the r bit of the file.\n");
                break;
            }
            case 225: {
                printf("\033[3m  225: Not a valid DOS disk\033[0m\n");
                cause();
                printf("  The disk in the drive is not an AmigaDOS disk, it has not been formatted, or it is corrupt.\n");
                recovery();
				printf("  Check to make sure you are using the correct disk. If you know the disk worked before, use a disk recovery program to salvage its files. If the disk has not been formatted, use FORMAT to do so.\n");
                break;
            }
            case 226: {
                printf("\033[3m  226: No disk in drive\033[0m\n");
                cause();
                printf("  The disk is not properly inserted in the specified drive.\n");
                recovery();
                printf("  Insert the appropriate disk in the specified drive.\n");
                break;
            }
            case 232: {
                printf("\033[3m  232: No more entries in directory\033[0m\n");
                cause();
                printf("  This indicates that the AmigaDOS call EXNEXT has no more entries in the directory you are examining.\n");
                recovery();
                printf("  Stop calling EXNEXT.\n");
                break;
            }
			case 233: {
				printf("\033[3m  233: Object is soft link\033[0m\n");
				cause();
				printf("  You tried to perform an operation on a soft link that should only be performed on a file or directory.\n");
				recovery();
				printf("  AmigaDOS uses Action_Read_Link to resolve the soft link and retries the operation.\n");
				break;
			}
            default: {
                printf("%s is an unrecognized error code.\n",argv[1]);
                break;
            }
        }
    }
}
